*******************************************************************************
*
*    Kmat - A matboard cutting calculator
*    Copyright (C)  2023 : Kurt Ebert
*
*    This program is free software: you can redistribute it and/or modify
*    it under the terms of the GNU General Public License as published by
*    the Free Software Foundation, either version 3 of the license, or
*    (at your option) any later version.
*
*    This program is distributed in the hope that it will be useful,
*    but WITHOUT ANY WARRANTY; without even the implied warranty of
*    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
*    GNU General Public License for more details.
*
*    You should have received a copy of the GNU General Public License
*    along with this program.  If not, see {<http:*www.gnu.org/licenses/>}
*
*    Web   : www.kurtebertphoto.com/kmat/
*    Email : kurt@kurtebertphoto.com
*
*******************************************************************************
*
*    Kmat Version 5.0 -- (1.1.2023)
*
*******************************************************************************

#include "hmg.ch"
d_declare ()
FUNCTION Main()
d_Pvars ()
d_Psets ()
d_main_win ()
RETURN NIL

*******************************************************************************

Function d_main_win ()
 DEFINE WINDOW Form_1 AT 100,100 WIDTH 935 HEIGHT 775 NOMAXIMIZE NOSIZE TITLE "Kmat - Matboard Calculator  /  Version 5.0  /  1.1.2023" MAIN
  END WINDOW
   d_keys ()
   d_Image_photo ()
   d_kmat_lic ()
   d_kmat_help ()
   d_kmat_extra ()
   d_main_menu ()
   d_main_window_fields ()
   Matcut()
   Main_window_Info ()
   Errorbox()
  END WINDOW
 ACTIVATE WINDOW Form_1
RETURN NIL

*******************************************************************************

* Drawing to show how to place and cut the matboard, located bottom center of main form
Function matcut()
   DRAW RECTANGLE IN WINDOW Form_1 AT 530,380 TO 680,630 PENCOLOR {0,0,0} PENWIDTH 2 
   DRAW LINE IN WINDOW Form_1 AT 550,380 TO 550,630
   DRAW LINE IN WINDOW Form_1 AT 650,380 TO 650,630
   DRAW LINE IN WINDOW Form_1 AT 530,430 TO 680,430
   DRAW LINE IN WINDOW Form_1 AT 530,580 TO 680,580
RETURN NIL

*******************************************************************************

* Drawing of an error box at project area if math error or bad data entered
Function Errorbox()
   DRAW RECTANGLE IN WINDOW Form_1 AT 85,310 TO 364,702 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {255,255,255}
   DRAW RECTANGLE IN WINDOW Form_1 AT 117,352 TO 312,660 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {180,180,180}
   DRAW RECTANGLE IN WINDOW Form_1 AT 125,360 TO 304,652 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {80,80,80}
   DRAW LINE IN WINDOW Form_1 AT 145,385 TO 284,632 PENCOLOR {255,153,0} PENWIDTH 1
   DRAW LINE IN WINDOW Form_1 AT 284,385 TO 145,632 PENCOLOR {255,153,0} PENWIDTH 1
RETURN NIL

*******************************************************************************

* Main function to draw mat board project
FUNCTION Matcalc()
      CleanSlate ()
      R_Pics ()
         if  Form_1.V1.value>0 .and. Form_1.V2.value>0 .and. Form_1.V3.value>0 .and. Form_1.V4.value>0
            Kcalc := 1
            Kphoto:= 0
            Math_pvars ()
            math_get_check ()
            mat_math ()
               if W3< 0 .or. W4< 0 .or. W5< 0 .or. W6< 0 .or. W7< 0 .or. W8< 0 .or. L3< 0 .or. L4< 0 .or. L5< 0 .or. L6< 0 .or. L7< 0 .or. L8< 0
                  Kcalc := 0
                  math_error ()
                  ERASE WINDOW Form_1
                  matcut()
                  errorbox()
               else
                  Form_1.Restore
                  matcut()
                     if  matw>0 .and. matl>0 .and. picw>0 .and. picl>0 .and. picw<matw .and. picl<matl .and. picw<=picl .and. matw<=matl
                        paint_mat ()
                     else
                        zero_fields ()
                        ERASE WINDOW Form_1
                        matcut()
                        errorbox()
                     endif
               endif
         endif
RETURN NIL

************************************************************************************************

* define public mem vars for math functions
Function Math_pvars ()
   Public Kname, cm, matw, matl, picw, picl, overlap, m12, m23, offw, offl
   Public rabit, matw_I, matl_I, picw_I, picl_I, matwidth, matlength, picwidth, piclength
   Public K1, K2, K3, K4, K5, U1, U2, U3, R1, R2, R3, R4, R5, T1, T2, T3
   Public x, y, x2, y2, vMax, S1, S2, xx2, yy2, xx, yy
   Public W3, W4, W5, W6, W7, W8, L3, L4, L5, L6, L7, L8
   Public yp, xxp, yyp, x2p, y2p, xx2p, yy2p
   Public AR, Golden
RETURN NIL

************************************************************************************************

* get form values and check inch vs mm
Function  math_get_check ()
   matwidth  := Form_1.V1.value
   matlength := Form_1.V2.value 
   picwidth  := Form_1.V3.value
   piclength := Form_1.V4.value
   overlap   := Form_1.V5.value
   m12       := Form_1.V6.value 
   m23       := Form_1.V7.value
   offw      := Form_1.V8.value
   offl      := Form_1.V9.value
   Kname     := Form_1.V10.value
   cm        := 25.40
   rabit     := 18

   if matwidth < 50 
      matw   := cm*matwidth
      matw_I := matwidth
   else
      matw   := matwidth
      matw_I := round((matwidth/cm),2)
   endif

   if matlength < 50
      matl := cm*matlength
      matl_I := matlength
   else
      matl := matlength
      matl_I := round((matlength/cm),2)
   endif

   if picwidth < 50
      picw   := cm*picwidth
      picw_I := picwidth
   else
      picw   := picwidth
      picw_I := round((picwidth/cm),2)
   endif

   if piclength < 50
      picl := cm*piclength
      picl_I := piclength
   else
      picl := piclength
      picl_I := round((piclength/cm),2)
   endif

   if (overlap*2) > (picw/2)
      Form_1.V5.value := 0
      overlap = 0
   endif

RETURN NIL

************************************************************************************************

* Math behind the answers
FUNCTION mat_math ()

   vMax  :=(392/matl)
   x     := 80
   y     := 310
   xx    := x+(matw*vmax)
   yy    := y+(matl*vmax)
 
   yp    := y+(392-(matw*vmax))/2
   xxp   := x+(matl*vmax)
   yyp   := yp+(matw*vmax)

   s1    := ((Matw-Picw)/2)
   s2    := ((Matl-Picl)/2)
 
   x2    := x+(((S1)+(overlap)-(Offw))*vmax)
   y2    := y+(((S2)+(overlap)+(Offl))*vmax)
   xx2   := x+(((s1+picw)-(overlap)-(Offw))*vmax)
   yy2   := y+(((S2+picl)-(overlap)+(Offl))*vmax)

   x2p   := x+(((S2)+(overlap)-(offl))*vmax)
   y2p   := yp+(((S1)+(overlap))-(offw))*vmax
   xx2p  := x+(((S2+picl)-(overlap)-(Offl))*vmax)
   yy2p  := yp+(((S1+picw)-(overlap))-(offw))*vmax

   AR    := Round(((picl/picw)*100),0)
   gold  := ((matl * matw) - (picl * picw)) / (picl * picw) 

   K1    := (matw-rabit)+(picw-(2*overlap))
   K2    := (matl-rabit)-(picl-(2*overlap))
   K3    := 4*(matw-rabit)
   K4    := K1*K2
   K5    := K4/K3
   U1    := (matl-rabit)-(picl-(2*overlap))
   U2    := U1/2
   U3    := Round((U2-K5),0)
   R1    := (matl-rabit)+(picl-(2*overlap))
   R2    := (matw-rabit)-(picw-(2*overlap))
   R3    := 4*(matl-rabit) 
   R4    := R1*R2
   R5    := R4/R3
   T1    := (matw-rabit)-(picw-(2*overlap))
   T2    := T1/2
   T3    := round((T2-R5),0)

   W3=(((matw-picw)+2*Overlap)/2)-offw
   W4=(((matw-picw)+2*Overlap)/2)+offw
   L3=(((matl-picl)+2*Overlap)/2)-offl
   L4=(((matl-picl)+2*Overlap)/2)+offl

   if m12 > 0
      W5=W3-m12
      L5=L3-m12
      W6=W4-m12
      L6=L4-m12
   else
      W5=0
      W6=0
      L5=0
      L6=0
      Form_1.V6.value := 0
   endif

   if m23 > 0 .and. m12> 0
      W7=W5-m23
      L7=L5-m23
      W8=W6-m23
      L8=L6-m23
   else
      W7=0
      W8=0
      L7=0
      L8=0
      Form_1.V7.value := 0
   endif

   if m23 > 0 .and. m12 = 0 
      Form_1.V7.value := 0
   endif

   if matw > matl 
      Form_1.V1.value := 0
   endif

   if picw > picl  
      Form_1.V3.value := 0
   endif

   Kname = ltrim(trim(Kname))
   if len(Kname) > 30
      Kname = substr(Kname,1,30)
   endif
   Form_1.V10.value :=  Kname

   Form_1.V20.value  := T3
   Form_1.V30.value  := U3
   Form_1.V40.value  := round(matw,0)
   Form_1.V45.value  := round(picw,0)
   Form_1.V50.value  := round(matl,0)
   Form_1.V55.value  := round(picl,0)
   Form_1.V60.value  := gold
   Form_1.V100.value := round(w3,0)
   Form_1.V101.value := round(w4,0)
   Form_1.V102.value := round(l3,0)
   Form_1.V103.value := round(l4,0)
   Form_1.V104.value := round(w5,0)
   Form_1.V105.value := round(w6,0)
   Form_1.V106.value := round(l5,0)
   Form_1.V107.value := round(l6,0)
   Form_1.V108.value := round(w7,0)
   Form_1.V109.value := round(w8,0)
   Form_1.V110.value := round(l7,0)
   Form_1.V111.value := round(l8,0)

RETURN NIL

************************************************************************************************

* If math error, clear mem and 0 fields
FUNCTION math_error ()

   W3 := 0
   W4 := 0
   W5 := 0
   W6 := 0
   W7 := 0
   W8 := 0
   L3 := 0
   L4 := 0
   L5 := 0
   L6 := 0
   L7 := 0
   L8 := 0

   Form_1.V100.value := round(w3,0)
   Form_1.V101.value := round(w4,0)
   Form_1.V102.value := round(l3,0)
   Form_1.V103.value := round(l4,0)
   Form_1.V104.value := round(w5,0)
   Form_1.V105.value := round(w6,0)
   Form_1.V106.value := round(l5,0)
   Form_1.V107.value := round(l6,0)
   Form_1.V108.value := round(w7,0)
   Form_1.V109.value := round(w8,0)
   Form_1.V110.value := round(l7,0)
   Form_1.V111.value := round(l8,0)

RETURN NIL

************************************************************************************************

* draw the mat project and load picture
FUNCTION paint_mat ()

   if HV > 0
      DRAW RECTANGLE IN WINDOW Form_1 AT x-20,y-20 TO x+392+20,y+392+20 PENCOLOR {212,208,200} PENWIDTH 0 FILLCOLOR {212,208,200}
      DRAW RECTANGLE IN WINDOW Form_1 AT x,yp TO xxp,yyp PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {255,255,255}

         if m23 > 0 .and. m12> 0
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12+m23)*vmax))-1, (y2p-((m12+m23)*vmax))-1 TO (xx2p+((m12+m23)*vmax))+1, (yy2p+((m12+m23)*vmax))+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {180,180,180}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12+m23)*vmax)), (y2p-((m12+m23)*vmax)) TO (xx2p+((m12+m23)*vmax)), (yy2p+((m12+m23)*vmax)) PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {180,180,180}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12+m23)*vmax))+1, (y2p-((m12+m23)*vmax))+1 TO (xx2p+((m12+m23)*vmax))-1, (yy2p+((m12+m23)*vmax))-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {180,180,180}
         endif

         if m12 > 0
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12)*vmax))-1, (y2p-((m12)*vmax))-1 TO (xx2p+((m12)*vmax))+1, (yy2p+((m12)*vmax))+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {210,210,210}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12)*vmax)), (y2p-((m12)*vmax)) TO (xx2p+((m12)*vmax)), (yy2p+((m12)*vmax)) PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {210,210,210}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2p-((m12)*vmax))+1, (y2p-((m12)*vmax))+1 TO (xx2p+((m12)*vmax))-1, (yy2p+((m12)*vmax))-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {210,210,210}
         endif

      DRAW RECTANGLE IN WINDOW Form_1 AT x2p-1,y2p-1 TO xx2p+1,yy2p+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {80,80,80} 
      DRAW RECTANGLE IN WINDOW Form_1 AT x2p,y2p TO xx2p,yy2p PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {80,80,80} 
      DRAW RECTANGLE IN WINDOW Form_1 AT x2p+1,y2p+1 TO xx2p-1,yy2p-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {80,80,80} 
      Want_photo()

    else
   
      DRAW RECTANGLE IN WINDOW Form_1 AT x-20,y-20 TO x+392+20,y+392+20 PENCOLOR {212,208,200} PENWIDTH 0 FILLCOLOR {212,208,200}
      DRAW RECTANGLE IN WINDOW Form_1 AT x,y TO xx,yy PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {255,255,255}
         
         if m23 > 0 .and. m12> 0
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12+m23)*vmax))-1, (y2-((m12+m23)*vmax))-1 TO (xx2+((m12+m23)*vmax))+1, (yy2+((m12+m23)*vmax))+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {180,180,180}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12+m23)*vmax)), (y2-((m12+m23)*vmax)) TO (xx2+((m12+m23)*vmax)), (yy2+((m12+m23)*vmax)) PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {180,180,180}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12+m23)*vmax))+1, (y2-((m12+m23)*vmax))+1 TO (xx2+((m12+m23)*vmax))-1, (yy2+((m12+m23)*vmax))-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {180,180,180}
         endif
  
         if m12 > 0
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12)*vmax))-1, (y2-((m12)*vmax))-1 TO (xx2+((m12)*vmax))+1, (yy2+((m12)*vmax))+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {210,210,210}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12)*vmax)), (y2-((m12)*vmax)) TO (xx2+((m12)*vmax)), (yy2+((m12)*vmax)) PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {210,210,210}
            DRAW RECTANGLE IN WINDOW Form_1 AT (x2-((m12)*vmax))+1, (y2-((m12)*vmax))+1 TO (xx2+((m12)*vmax))-1, (yy2+((m12)*vmax))-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {210,210,210}
         endif 

      DRAW RECTANGLE IN WINDOW Form_1 AT x2-1,y2-1 TO xx2+1,yy2+1 PENCOLOR {128,128,128} PENWIDTH 1 FILLCOLOR {80,80,80}
      DRAW RECTANGLE IN WINDOW Form_1 AT x2,y2 TO xx2,yy2 PENCOLOR {255,255,255} PENWIDTH 1 FILLCOLOR {80,80,80}
      DRAW RECTANGLE IN WINDOW Form_1 AT x2+1,y2+1 TO xx2-1,yy2-1 PENCOLOR {0,0,0} PENWIDTH 1 FILLCOLOR {80,80,80}
      Want_photo()
   endif

RETURN NIL

************************************************************************************************

* Another error function to zero out mem and replace fields
FUNCTION zero_fields ()

   Kcalc  := 0
   matw   := 0
   matl   := 0
   picw   := 0
   picl   := 0
   matw_I := 0
   matl_I := 0 

   W3 := 0
   W4 := 0
   W5 := 0
   W6 := 0
   W7 := 0
   W8 := 0
   L3 := 0
   L4 := 0
   L5 := 0
   L6 := 0
   L7 := 0
   L8 := 0

RETURN NIL

************************************************************************************************

* declare main public mem vars
FUNCTION d_Pvars ()
   Public Kcalc, HV, HVM, Kphoto, Rpics
   Rpics := 0
   Kphoto:= 0
   Kcalc := 0
   HV    := 0
   HVM   := 0
RETURN NIL

************************************************************************************************

* set navigation
FUNCTION d_Psets ()
Set Navigation Extended
RETURN NIL

************************************************************************************************

* declare help windows
  FUNCTION d_declare ()
   DECLARE WINDOW kmat_lic
   DECLARE WINDOW kmat_help
   DECLARE WINDOW kmat_extra
RETURN NIL

************************************************************************************************

* set esc key
FUNCTION d_keys ()
ON KEY ESCAPE OF FORM_1 ACTION Form_1.Release
RETURN NIL

************************************************************************************************

* Main window information labels
FUNCTION  Main_window_Info ()
   @ 505,405 LABEL L201 PARENT Form_1 WIDTH 300 VALUE "    W1 - Mark from top of mat down "
   @ 686,403 LABEL L202 PARENT Form_1 WIDTH 300 VALUE "   W2 - Mark from bottom of mat up"
   @ 586,329 LABEL L203 PARENT Form_1 WIDTH 50 VALUE "L1-Left"
   @ 586,639 LABEL L204 PARENT Form_1 WIDTH 50 VALUE "L2-Right"

   @ 545,710 LABEL L205 PARENT Form_1 WIDTH 250 VALUE "Place matboard with it's length,"
   @ 560,710 LABEL L206 PARENT Form_1 WIDTH 250 VALUE "longer side (Horizontal)"                
   @ 590,710 LABEL L207 PARENT Form_1 WIDTH 250 VALUE " ***  See Drawing  *** "  
   @ 620,710 LABEL L209 PARENT Form_1 WIDTH 250 VALUE "Measure, mark, draw, cut,"
   @ 635,710 LABEL L211 PARENT Form_1 WIDTH 250 VALUE "from the back of matboard"
   @ 650,710 LABEL L212 PARENT Form_1 WIDTH 250 VALUE " "

   @ 545,50 LABEL L215 PARENT Form_1 WIDTH 325 VALUE "Use ( Landscape Offset ) to optically center / "
   @ 560,50 LABEL L216 PARENT Form_1 WIDTH 325 VALUE "bottom weight a landscape orientation project"                  
   @ 590,50 LABEL L217 PARENT Form_1 WIDTH 250 VALUE "Use ( Portrait Offset ) to optically center /"           
   @ 605,50 LABEL L219 PARENT Form_1 WIDTH 250 VALUE "bottom weight a  portrait orientation project"      
   @ 635,50 LABEL L220 PARENT Form_1 WIDTH 250 VALUE "Suggested optical centering values shown"
   @ 650,50 LABEL L221 PARENT Form_1 WIDTH 325 VALUE "just right of corresponding offset fields"
   @ 665,50 LABEL L223 PARENT Form_1 WIDTH 5 VALUE ""
   @ 665,70 LABEL L224 PARENT Form_1 WIDTH 5 VALUE ""
     *
RETURN NIL

************************************************************************************************

Function d_main_window_fields ()
   @ 32,30 LABEL L1 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE "Mat Width    (Inch or mm)" bold
   @ 30,210 TEXTBOX V1 PARENT Form_1 WIDTH 60 NUMERIC 
   @ 35,276 Label A1  PARENT Form_1 WIDTH 10 VALUE ""
   @ 62,30 LABEL L2 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE "Mat Length  (Inch or mm)" bold
   @ 60,210 TEXTBOX V2 PARENT Form_1 WIDTH 60 NUMERIC 
   @ 65,276 Label A2  PARENT Form_1 WIDTH 10 VALUE ""
   @ 102,30 LABEL L3 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE "Photo Width    (Inch or mm)" bold
   @ 100,210 TEXTBOX V3 PARENT Form_1 WIDTH 60 NUMERIC
   @ 105,276 Label A3  PARENT Form_1 WIDTH 10 VALUE ""
   @ 132,30 LABEL L4 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE "Photo Length  (Inch or mm)" bold
   @ 130,210 TEXTBOX V4 PARENT Form_1 WIDTH 60 NUMERIC 
   @ 135,276 Label A4  PARENT Form_1 WIDTH 10 VALUE ""
   @ 172,30 LABEL L5 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE "    Base Mat Overlap  (mm)"
   @ 170,210 TEXTBOX V5 PARENT Form_1 WIDTH 45 NUMERIC ON LOSTFOCUS Matcalc() 
   @ 202,30 LABEL L6 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE " Mat-1 to Mat-2 Setback (mm)"
   @ 200,210 TEXTBOX V6 PARENT Form_1 WIDTH 45 NUMERIC  
   @ 232,30 LABEL L7 PARENT Form_1 WIDTH 170 RIGHTALIGN VALUE " Mat-2 to Mat-3 Setback (mm)"
   @ 230,210 TEXTBOX V7 PARENT Form_1 WIDTH 45 NUMERIC 

   @ 272,35 LABEL L8 PARENT Form_1 WIDTH 160 RIGHTALIGN VALUE "Landscape Offset (mm)"
   @ 270,205 TEXTBOX V8 PARENT Form_1 WIDTH 40 NUMERIC ON LOSTFOCUS Chk_Port() 
   @ 270,250 TEXTBOX V20 PARENT Form_1 WIDTH 30 NUMERIC RIGHTALIGN NOTABSTOP READONLY

   @ 302,35 LABEL L9 PARENT Form_1 WIDTH 160 RIGHTALIGN VALUE "Portrait Offset (mm)"
   @ 300,205 TEXTBOX V9 PARENT Form_1 WIDTH 40 NUMERIC ON LOSTFOCUS Chk_Port() 
   @ 300,250 TEXTBOX V30 PARENT Form_1 WIDTH 30 NUMERIC RIGHTALIGN NOTABSTOP READONLY

   @ 30,300  BUTTON B1 PARENT Form_1 CAPTION "Calculate" WIDTH 65 BOLD ONCLICK Matcalc()
   @ 30,370 BUTTON B2 PARENT Form_1 CAPTION "Orientation" WIDTH 75 BOLD ONCLICK Flipmat()
   @ 30,450  BUTTON B3 PARENT Form_1 CAPTION "Hide" WIDTH 35 BOLD ONCLICK Want_photo()
   @ 30,490 BUTTON B4 PARENT Form_1 CAPTION "Pdf" WIDTH 30 BOLD ONCLICK Pdfprt()
   @ 30,525 BUTTON B6 PARENT Form_1 CAPTION "Txt" WIDTH 30 BOLD ONCLICK TxtPrt()
   @ 30,560 BUTTON B7 PARENT Form_1 CAPTION "Screen" WIDTH 70 BOLD ONCLICK Screen_Prt()
   @ 30,635 BUTTON B8 PARENT Form_1 CAPTION "Load Picture" WIDTH 80 BOLD ONCLICK Picload ()
 
   @ 343,92 LABEL L222 PARENT Form_1 WIDTH 110 VALUE "Golden Ratio (1.62)"
   @ 340,210 TEXTBOX V60 PARENT Form_1 WIDTH 45 NUMERIC RIGHTALIGN NOTABSTOP READONLY

   @ 378,50 LABEL L10 PARENT Form_1 WIDTH 150 RIGHTALIGN VALUE "Photo Name / Max 30" 
   @ 398,35 TEXTBOX V10 PARENT Form_1 WIDTH 220

   @ 440,73 LABEL L40 PARENT Form_1 WIDTH 160 RIGHTALIGN VALUE "Artwork     Matboard"
   @ 478,42 LABEL L50 PARENT Form_1 WIDTH 70 RIGHTALIGN VALUE "Metric  (mm)"
   @ 462,125 TEXTBOX V45 PARENT Form_1 WIDTH 45 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 462,185 TEXTBOX V40 PARENT Form_1 WIDTH 45 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 492,125 TEXTBOX V55 PARENT Form_1 WIDTH 45 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 492,185 TEXTBOX V50 PARENT Form_1 WIDTH 45 NUMERIC RIGHTALIGN NOTABSTOP READONLY

   @ 62,750 LABEL L100 PARENT Form_1 WIDTH 70 VALUE  "Mat-1  W1"
   @ 60,820 TEXTBOX V100 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 60,876 Label 1005 PARENT Form_1 WIDTH 10 VALUE ""
   @ 92,750 LABEL L101 PARENT Form_1 WIDTH 70 VALUE  "Mat-1  W2"
   @ 90,820 TEXTBOX V101 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 90,876 Label 1015 PARENT Form_1 WIDTH 10 VALUE ""
   @ 122,750 LABEL L102 PARENT Form_1 WIDTH 70 VALUE  "Mat-1  L1"
   @ 120,820 TEXTBOX V102 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 120,876 Label 1025 PARENT Form_1 WIDTH 10 VALUE ""
   @ 152,750 LABEL L103 PARENT Form_1 WIDTH 70 VALUE "Mat-1  L2"
   @ 150,820 TEXTBOX V103 PARENT Form_1 WIDTH 50NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 150,876 Label 1035 PARENT Form_1 WIDTH 10 VALUE ""
   @ 212,750 LABEL L104 PARENT Form_1 WIDTH 70 VALUE "Mat-2  W1"
   @ 210,820 TEXTBOX V104 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 210,876 Label 1045 PARENT Form_1 WIDTH 10 VALUE ""
   @ 242,750 LABEL L105 PARENT Form_1 WIDTH 70 VALUE "Mat-2  W2"
   @ 240,820 TEXTBOX V105 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 240,876 Label 1055 PARENT Form_1 WIDTH 10 VALUE ""
   @ 272,750 LABEL L106 PARENT Form_1 WIDTH 70 VALUE "Mat-2  L1"
   @ 270,820 TEXTBOX V106 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 270,876 Label 1065 PARENT Form_1 WIDTH 10 VALUE ""
   @ 302,750 LABEL L107 PARENT Form_1 WIDTH 70 VALUE "Mat-2  L2"
   @ 300,820 TEXTBOX V107 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 300,876 Label 1075 PARENT Form_1 WIDTH 10 VALUE ""
   @ 362,750 LABEL L108 PARENT Form_1 WIDTH 70 VALUE "Mat-3  W1"
   @ 360,820 TEXTBOX V108 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 360,876 Label 1085 PARENT Form_1 WIDTH 10 VALUE ""
   @ 392,750 LABEL L109 PARENT Form_1 WIDTH 70 VALUE "Mat-3  W2"
   @ 390,820 TEXTBOX V109 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 390,876 Label 1095 PARENT Form_1 WIDTH 10 VALUE ""
   @ 422,750 LABEL L110 PARENT Form_1 WIDTH 70 VALUE "Mat-3  L1"
   @ 420,820 TEXTBOX V110 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 420,876 Label 1105 PARENT Form_1 WIDTH 10 VALUE ""
   @ 452,750 LABEL L111 PARENT Form_1 WIDTH 70 VALUE "Mat-3  L2"
   @ 450,820 TEXTBOX V111 PARENT Form_1 WIDTH 50 NUMERIC RIGHTALIGN NOTABSTOP READONLY
   @ 450,876 Label 1115 PARENT Form_1 WIDTH 10 VALUE ""

RETURN NIL

************************************************************************************************
* License window
FUNCTION d_kmat_lic ()
   DEFINE WINDOW kmat_lic AT 50,50 WIDTH 524 HEIGHT 417 TITLE 'License' NOSHOW NOAUTORELEASE

       DEFINE BUTTON Button_1
       ROW	340
       COL	211
       CAPTION 'Close'
       ACTION	ThisWindow.Hide
       END BUTTON

       @ 15,184 LABEL L0  PARENT kmat_lic WIDTH 450 VALUE "  Kmat -- Matboard Calculator"
       @ 30,184 LABEL L1  PARENT kmat_lic WIDTH 450 VALUE "     Version 5.0 -- (1.1.2023)"
       @ 45,184 LABEL L2  PARENT kmat_lic WIDTH 450 VALUE "Copyrite (C) 2023:  Kurt Ebert"
       @ 60,65  LABEL L3  PARENT kmat_lic WIDTH 450 VALUE ""
       @ 75,65  LABEL L4  PARENT kmat_lic WIDTH 450 VALUE "This program is free software: you can redistribute it and/or modify" 
       @ 90,65  LABEL L5  PARENT kmat_lic WIDTH 450 VALUE "it under the terms of the GNU General Public License as published by" 
       @ 105,65 LABEL L6  PARENT kmat_lic WIDTH 450 VALUE "the Free Software Foundation, version 3 of the license."              
       @ 120,65 LABEL L7  PARENT kmat_lic WIDTH 450 VALUE ""                                                                     
       @ 135,65 LABEL L8  PARENT kmat_lic WIDTH 450 VALUE "This program is distributed in the hope that it will be useful,"      
       @ 150,65 LABEL L9  PARENT kmat_lic WIDTH 450 VALUE "but WITHOUT ANY WARRANTY; without even the implied warranty of"       
       @ 165,65 LABEL L10 PARENT kmat_lic WIDTH 450 VALUE "MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See"             
       @ 180,65 LABEL L11 PARENT kmat_lic WIDTH 450 VALUE "the GNU General Public License for more details."                     
       @ 195,65 LABEL L12 PARENT kmat_lic WIDTH 450 VALUE ""                                                                     
       @ 210,65 LABEL L13 PARENT kmat_lic WIDTH 450 VALUE "You should have received a copy of the GNU General Public License"    
       @ 225,65 LABEL L14 PARENT kmat_lic WIDTH 450 VALUE "along with this program. If not, see {<http://www.gnu.org/licenses/>}"
       @ 240,65 LABEL L15 PARENT kmat_lic WIDTH 450 VALUE ""
       @ 255,210 LABEL L16 PARENT kmat_lic WIDTH 450 VALUE "Contact Information"
       @ 280,179 hyperlink ip1 width 300 value "Email: kurt@kurtebertphoto.com" address "kurt@kurtebertphoto.com" handcursor
       @ 294,260 LABEL L17 PARENT kmat_lic WIDTH 25 VALUE "~"
       @ 306,184 hyperlink ip2 width 300 value "www.kurtebertphoto.com/kmat" address "http://kurtebertphoto.com/kmat" handcursor
   END WINDOW
RETURN NIL

************************************************************************************************

* Help Window
FUNCTION d_kmat_help ()
   DEFINE WINDOW kmat_help AT 50,50 WIDTH 524 HEIGHT 580 TITLE 'Help' NOSHOW NOAUTORELEASE
 
       DEFINE BUTTON Button_2
       ROW	498
       COL	211
       CAPTION 'Close'
       ACTION	ThisWindow.Hide
       END BUTTON

       @ 15,65  LABEL H0  PARENT kmat_help WIDTH 500 VALUE "First 4 fields are mandatory to cut a matboard"
       @ 30,65  LABEL H1  PARENT kmat_help WIDTH 500 VALUE "First 4 fields take either inch or mm values"
       @ 45,65  LABEL H2  PARENT kmat_help WIDTH 500 VALUE "Length field must be equal or larger than width"
       @ 60,65  LABEL H3  PARENT kmat_help WIDTH 500 VALUE "Numbers less than 50 are calculated as inches"
       @ 75,65  LABEL H4  PARENT kmat_help WIDTH 500 VALUE "Decimal numbers allowed (14.75)"
       @ 90,65  LABEL H5  PARENT kmat_help WIDTH 500 VALUE "Photo size needs to be less than mat size"
       @ 105,65 LABEL H6  PARENT kmat_help WIDTH 500  VALUE " " 
       @ 120,65 LABEL H7  PARENT kmat_help WIDTH 500  VALUE "Mat Overlap is in mm, and can be positive or negative " 
       @ 135,65 LABEL H8  PARENT kmat_help WIDTH 500 VALUE "Mat set backs are positive only and in mm" 
       @ 150,65 LABEL H9  PARENT kmat_help WIDTH 500 VALUE " " 
       @ 165,65 LABEL H10 PARENT kmat_help WIDTH 500 VALUE "Calculated offset values are displayed just right of offset fields" 
       @ 180,65 LABEL H11 PARENT kmat_help WIDTH 500 VALUE "Use correct offset field for project orientation"    
       @ 195,65 LABEL H12 PARENT kmat_help WIDTH 500 VALUE "Blank / Zero offsets = project centered and defaults to landscape"                       
       @ 210,65 LABEL H13 PARENT kmat_help WIDTH 500 VALUE "Either offset field > 0 will rotate project automatically " 
       @ 225,65 LABEL H14 PARENT kmat_help WIDTH 500 VALUE "Entering a very small number in portrait offset will force rotation,"
       @ 240,65 LABEL H15 PARENT kmat_help WIDTH 500 VALUE "without changing mat cuts and keep program in auto rotation"
       @ 255,65 LABEL H16 PARENT kmat_help WIDTH 500 VALUE "Example: 0.1 in portrate offset"                   
       @ 270,65 LABEL H17 PARENT kmat_help WIDTH 500 VALUE "If you use the Orientation Button you leave auto mode"
       @ 285,65 LABEL H18 PARENT kmat_help WIDTH 500 VALUE " "
       @ 300,65 LABEL H19 PARENT kmat_help WIDTH 500 VALUE " "
       @ 315,65 LABEL H20 PARENT kmat_help WIDTH 500 VALUE "Buttons"                                                                                                                                       
       @ 330,65 LABEL H21 PARENT kmat_help WIDTH 500 VALUE "Calculate = Re-do all math after a change and save for reporting"                              
       @ 345,65 LABEL H22 PARENT kmat_help WIDTH 500 VALUE "Orientation = Needed when using both offsets at once"    
       @ 360,65 LABEL H23 PARENT kmat_help WIDTH 500 VALUE "Hide = Replace picture with dark grey, prefered by some to visulize"                        
       @ 375,65 LABEL H24 PARENT kmat_help WIDTH 500 VALUE "Pdf / Txt / Screen = Reports as pdf, text file or screen capture"                                    
       @ 390,65 LABEL H25 PARENT kmat_help WIDTH 500 VALUE "Load Picture = View a (Jpg) of you own in the program"                                             
       @ 405,65 LABEL H26 PARENT kmat_help WIDTH 500 VALUE "Note - Any re-calc and program will default to normal pictures"                                  
       @ 420,65 LABEL H27 PARENT kmat_help WIDTH 500 VALUE "Need to be jpg and not masive in size "                                                                                                                                                      
       @ 435,65 LABEL H28 PARENT kmat_help WIDTH 500 VALUE " "                                                                                                                                                      
       @ 450,65 LABEL H29 PARENT kmat_help WIDTH 500 VALUE " "                                                                                                                                                       
       @ 465,65 LABEL H30 PARENT kmat_help WIDTH 500 VALUE " "                                                                                                                                                     
   END WINDOW
RETURN NIL

************************************************************************************************

* Extra features window
FUNCTION d_kmat_extra ()
    DEFINE WINDOW kmat_extra AT 50,50 WIDTH 575 HEIGHT 510 TITLE 'Extra Features' NOSHOW NOAUTORELEASE
 
       DEFINE BUTTON Button_3
       ROW	420
       COL	222
       CAPTION 'Close'
       ACTION	ThisWindow.Hide
       END BUTTON

       @ 15,65  LABEL HA0  PARENT kmat_help WIDTH 450 VALUE ""
       @ 30,65  LABEL HA1  PARENT kmat_help WIDTH 450 VALUE "A companion program for the K-Mat Calculator is "
       @ 45,65  LABEL HA2  PARENT kmat_help WIDTH 450 VALUE "my Golden Ratio Print Calculator"
       @ 60,65  LABEL HA3  PARENT kmat_help WIDTH 450 VALUE ""
       @ 75,65  LABEL HA4  PARENT kmat_help WIDTH 450 VALUE "It is also possible for you to load your own pictures"
       @ 90,65  LABEL HA5  PARENT kmat_help WIDTH 450 VALUE "for the program to use every day as default"
       @ 105,65 LABEL HA6  PARENT kmat_help WIDTH 450 VALUE "Please eMail me for instructions"
       @ 120,65 LABEL HA7  PARENT kmat_help WIDTH 450 VALUE ""
       @ 135,65 LABEL HA8  PARENT kmat_help WIDTH 450 VALUE ""
       @ 150,65 LABEL HA9  PARENT kmat_help WIDTH 450 VALUE ""
       @ 165,65 LABEL HA10 PARENT kmat_help WIDTH 450 VALUE ""
       @ 180,65 LABEL HA11 PARENT kmat_help WIDTH 450 VALUE ""
       @ 195,65 LABEL HA12 PARENT kmat_help WIDTH 450 VALUE ""
       @ 210,65 LABEL HA13 PARENT kmat_help WIDTH 450 VALUE ""
       @ 225,65 LABEL HA14 PARENT kmat_help WIDTH 450 VALUE ""
       @ 240,65 LABEL HA15 PARENT kmat_help WIDTH 450 VALUE ""
       @ 255,65 LABEL HA16 PARENT kmat_help WIDTH 450 VALUE ""
       @ 270,65 LABEL HA17 PARENT kmat_help WIDTH 450 VALUE ""
       @ 285,65 LABEL HA18 PARENT kmat_help WIDTH 450 VALUE ""
       @ 300,65 LABEL HA19 PARENT kmat_help WIDTH 450 VALUE ""
       @ 315,65 LABEL HA20 PARENT kmat_help WIDTH 450 VALUE ""
       @ 330,65 LABEL HA21 PARENT kmat_help WIDTH 450 VALUE ""
       @ 345,65 LABEL HA22 PARENT kmat_help WIDTH 450 VALUE ""
       @ 360,65 LABEL HA23 PARENT kmat_help WIDTH 450 VALUE ""
       @ 375,65 LABEL HA24 PARENT kmat_help WIDTH 450 VALUE ""
       @ 390,65 LABEL HA25 PARENT kmat_help WIDTH 450 VALUE ""
      END WINDOW                                                                                             
RETURN NIL

************************************************************************************************

* define main menu
FUNCTION d_main_menu ()
   DEFINE MAIN MENU OF Form_1
     DEFINE POPUP "File" 
         MENUITEM "Exit" ACTION Form_1.Release
      END POPUP 
      DEFINE POPUP "About" 
         MENUITEM "License" ACTION kmat_lic.Show
      END POPUP 
      DEFINE POPUP "Help" 
         MENUITEM "Help" ACTION kmat_help.Show
         MENUITEM "Extra Features" ACTION kmat_extra.Show
      END POPUP 
   END MENU
RETURN NIL

************************************************************************************************

* define photo 
FUNCTION d_Image_photo ()
   DEFINE IMAGE Img1
   PARENT Form_1
   ROW 80
   COL 310
   STRETCH .t.
   VISIBLE .f.
   END IMAGE
RETURN NIL

************************************************************************************************

  * Screen Capture Report
   FUNCTION Screen_prt()
   *
   *  PRINTWINDOW ( cWindowName , lPreview , ldialog , nRow , nCol , nWidth , nHeight ) ***
   *  SAVEWINDOW  ( cWindowName , cFileName , nRow , nCol , nWidth , nHeight )          ***
   *
   if Kcalc > 0 
   * SAVEWINDOW ("Form_1", "Kmat.bmp")
   PRINTWINDOW ("Form_1", .t., .t.)
   endif
   RETURN NIL

************************************************************************************************

  * Manual override of project orentation
   FUNCTION Flipmat()
      if Kcalc > 0
         HVM := 1
            if HV=0
               HV:=1
            else
               HV:=0
            endif
         DRAW RECTANGLE IN WINDOW Form_1 AT x-20,y-20 TO x+392+20,y+392+20 PENCOLOR {212,208,200} PENWIDTH 0 FILLCOLOR {212,208,200}
         Form_1.Restore
         Matcalc()
      endif
   Return Nil

**********************************************************************************************
 
  * Check value of fields to auto rotate project
   Function Chk_Port()
    If HVM = 0
      if Form_1.V9.value <> 0 .and. Form_1.V8.value = 0
         HV:=1
       else
         HV:=0
      endif
    Endif
    Form_1.Restore
   Return Nil

**********************************************************************************************

  * Flip to load or hide photo in project
   Function Want_photo()
   if Kcalc > 0
     If Kphoto = 0
         Kphoto := 1
         Loadpic ()
      else
         CleanSlate ()
     Endif
   endif
   Return Nil

*********************************************************************************************

* Hide, Release and re-define image to clear for new image loading
   Function CleanSlate ()
   Form_1.Img1.Hide
   Form_1.img1.Release
   *
   DEFINE IMAGE Img1
   PARENT Form_1
   ROW 80
   COL 310
   STRETCH .t.
   VISIBLE .f.
   END IMAGE
   *
   RETURN NIL 

*********************************************************************************************

* paint landscape picture
   Function Landscape ()
      Form_1.img1.row := (x2+1)
      Form_1.img1.col := (y2+1)
      Form_1.img1.width := ((yy2-1)-(y2+1))
      Form_1.img1.height:= ((xx2-1)-(x2+1))
      Form_1.Img1.Show
   Return Nil

*********************************************************************************************

* paint portrait picture
   Function Portrait ()
      Form_1.img1.row := (x2p+1)
      Form_1.img1.col := (y2p+1)
      Form_1.img1.width := ((yy2p-1)-(y2p+1))
      Form_1.img1.height:= ((xx2p-1)-(x2p+1))
      Form_1.Img1.Show
   Return Nil

**********************************************************************************************

* load photograph with correct aspect-ratio and orientation for project picture painting
   FUNCTION loadpic()
    if Kcalc = 1
     if Kphoto = 1
      if Rpics = 1
        CleanSlate ()
         if HV = 0
            if AR >= 100 .and. AR < 112
               Form_1.img1.picture := "Pictures/H100.jpg"
            endif
            if AR >= 112 .and. AR < 129
               Form_1.img1.picture := "Pictures/H125.jpg"
            endif
            if AR >= 129 .and. AR < 136
               Form_1.img1.picture := "Pictures/H133.jpg"
            endif
            if AR >= 136 .and. AR < 145
               Form_1.img1.picture := "Pictures/H140.jpg"
            endif
            if AR >= 145 .and. AR < 156
               Form_1.img1.picture := "Pictures/H150.jpg"
            endif
            if AR >= 156 .and. AR < 170
               Form_1.img1.picture := "Pictures/H166.jpg"
            endif
            if AR >= 170 .and. AR < 185
               Form_1.img1.picture := "Pictures/H175.jpg"
            endif
            if AR >= 185 .and. AR < 225
               Form_1.img1.picture := "Pictures/H200.jpg"
            endif
            if AR >= 225 
               Form_1.img1.picture := "Pictures/H300.jpg"
            endif
            Landscape ()
         else
            if AR >= 100 .and. AR < 112
               Form_1.img1.picture := "Pictures/H100.jpg"
            endif
            if AR >= 112 .and. AR < 129
               Form_1.img1.picture := "Pictures/P125.jpg"
            endif
            if AR >= 129 .and. AR < 136
               Form_1.img1.picture := "Pictures/P133.jpg"
            endif
            if AR >= 136 .and. AR < 145
               Form_1.img1.picture := "Pictures/P140.jpg"
            endif
            if AR >= 145 .and. AR < 156
               Form_1.img1.picture := "Pictures/P150.jpg"
            endif
            if AR >= 156 .and. AR < 170
               Form_1.img1.picture := "Pictures/P166.jpg"
            endif
            if AR >= 170 .and. AR < 185
               Form_1.img1.picture := "Pictures/P175.jpg"
            endif
            if AR >= 185 .and. AR < 225
               Form_1.img1.picture := "Pictures/P200.jpg"
            endif
            if AR >= 225
               Form_1.img1.picture := "Pictures/P300.jpg"
            endif
            Portrait ()
         endif
      endif
     endif
    endif
   RETURN NIL

**********************************************************************************************

* Check to see if all pictures are avaliable
   FUNCTION R_pics ()
   if file ("Pictures/H100.jpg") .and. file ("Pictures/P125.jpg") .and.file ("Pictures/P133.jpg") .and. file ("Pictures/P140.jpg") .and. file ("Pictures/P150.jpg") .and. file ("Pictures/P166.jpg") .and. file ("Pictures/P175.jpg") .and. file ("Pictures/P200.jpg");
      .and. file ("Pictures/P300.jpg") .and. file ("Pictures/H125.jpg") .and. file ("Pictures/H133.jpg") .and. file ("Pictures/H140.jpg") .and. file ("Pictures/H150.jpg") .and. file ("Pictures/H166.jpg") .and. file ("Pictures/H175.jpg") .and. file ("Pictures/H200.jpg");
      .and. file ("Pictures/H300.jpg") 
      Rpics := 1
   else
      Rpics := 0
   endif
   RETURN NIL

**********************************************************************************************

  * Txt Report
   FUNCTION Txtprt()
   local padx, ccc
   padx := 7
   *
   if Kcalc > 0
   set alternate to "Kmat.txt"
   set alternate on
   ?
   ?
   if len(ltrim(trim(Kname))) > 0
      pady := (75-len(ltrim(trim(Kname))))/2
   ? space(pady), ltrim(trim(Kname))
   else
   ?
   endif
   ? space(5), "_____________________________________________________________"
   ?
   ? space(10),  "  Matboard Width (inch/mm) :", space(1), alltrim(str(matw_I)),space(padx-len (alltrim(str(matw_I)))), alltrim(str(round(matw,0)))
   ? space(10),  " Matboard Length (inch/mm) :", space(1), alltrim(str(matl_I)),space(padx-len (alltrim(str(matl_I)))), alltrim(str(round(matl,0)))
   ?  
   ? space(10),  " Art-Photo Width (inch/mm) :", space(1), alltrim(str(picw_I)),space(padx-len (alltrim(str(picw_I)))), alltrim(str( round(picw,0)))
   ? space(10),  "Art-Photo Length (inch/mm) :", space(1), alltrim(str(picl_I)),space(padx-len (alltrim(str(picl_I)))), alltrim(str( round(picl,0)))
   ?
   ? space(10),  "     Base Mat Overlap (mm) :", space(1), alltrim(str(overlap)) 
   *
   if m12 <> 0 
   ? space(10),  " Mat1 to Mat2 Setback (mm) :", space(1), alltrim(str(m12)) 
   else
   ? space(10),  " Mat1 to Mat2 Setback (mm) :", space(1),""
   endif  
   *
   if m23 <> 0   
   ? space(10),  " Mat2 to Mat2 Setback (mm) :", space(1), alltrim(str(m23))      
   else
   ? space(10),  " Mat2 to Mat2 Setback (mm) :", space(1), ""
   endif
   ?
   if offw <> 0
   ? space(10),  "  Photo Width Offset  (mm) :", space(1), alltrim(str(offw))
   else
   ? space(10),  "  Photo Width Offset  (mm) :", space(1), ""
   endif
   if offl <> 0    
   ? space(10),  "  Photo Length Offset (mm) :", space(1), alltrim(str(offl))     
   else
   ? space(10),  "  Photo Length Offset (mm) :", space(1), ""
   endif
   ? 
   ? space(10),  "  Photo Width Optical Cntr :", space(1),  alltrim(str(t3)) 
   ? space(10),  " Photo Length Optical Cntr :", space(1),  alltrim(str(u3)) 
   ? space(5), "_____________________________________________________________"
   ?
   ? space(29),  "Mat1 W1 :", space(1), ltrim(str(round(w3,0))) 
   ? space(29),  "Mat1 W2 :", space(1), ltrim(str(round(w4,0)))
   ? space(29),  "Mat1 L1 :", space(1), ltrim(str(round(l3,0)))
   ? space(29),  "Mat1 L2 :", space(1), ltrim(str(round(l4,0)))
   *
   if w5>0 .and. w6>0 .and. l5>0 .and. l6>0
   ?
   ? space(29), "Mat2 W1 :", space(1), ltrim(str(round(w5,0)))
   ? space(29), "Mat2 W2 :", space(1), ltrim(str(round(w6,0)))
   ? space(29), "Mat2 L1 :", space(1), ltrim(str(round(l5,0)))
   ? space(29), "Mat2 L2 :", space(1), ltrim(str(round(l6,0)))
   endif
   *
   if w7>0 .and. w8>0 .and. l7>0 .and. l8>0
   ?
   ? space(29), "Mat3 W1 :", space(1), ltrim(str(round(w7,0)))
   ? space(29), "Mat3 W2 :", space(1), ltrim(str(round(w8,0)))
   ? space(29), "Mat3 L1 :", space(1), ltrim(str(round(l7,0)))
   ? space(29), "Mat3 L2 :", space(1), ltrim(str(round(l8,0)))
   endif
   *
   ? space(5), "_____________________________________________________________"
   ?
   ? 
   ?
   set alternate off
   set alternate to
   if file ("AkelPad.Exe")
   Execute file "AkelPad.exe" Parameters "Kmat.txt"
   else
   Execute file "NotePad.exe" Parameters "Kmat.txt"
   endif
   endif
   RETURN NIL

************************************************************************************************

   * Pdf Report
   FUNCTION PdfPrt()
   if Kcalc > 0
    SELECT PRINTER DEFAULT TO PdfRpt PREVIEW
     If PdfRpt
      START PRINTDOC 
       START PRINTPAGE 
         @ 23,108 Print ltrim(trim(Kname)) Center Font "Lucenda Console" Size 11
         @ 25,108 Print "____________________________________________________________" Center Font "Lucenda Console" Size 11
         *  
         @ 33,103 Print "Matboard  Width -- (In, mm)" Font "Lucenda Console" Size 11 Right
         @ 33,108 print ":" Font "Lucenda Console" Size 11
         @ 33,123 Print alltrim(str(matw_I)) Font "Lucenda Console" Size 11 Right 
         @ 33,143 Print alltrim(str(round(matw,0))) Font "Lucenda Console" Size 11 Right
         @ 38,103 Print "Matboard  Length -- (In, mm)" Font "Lucenda Console" Size 11 Right
         @ 38,108 print ":" Font "Lucenda Console" Size 11
         @ 38,123 Print alltrim(str(matl_I)) Font "Lucenda Console" Size 11 Right 
         @ 38,143 Print alltrim(str(round(matl,0))) Font "Lucenda Console" Size 11 right 
         * 
         @ 46,103 Print "Art-Photo  Width -- (In, mm)" Font "Lucenda Console" Size 11 Right
         @ 46,108 print ":" Font "Lucenda Console" Size 11
         @ 46,123 Print alltrim(str(picw_I)) Font "Lucenda Console" Size 11 Right 
         @ 46,143 Print alltrim(str(round(picw,0))) Font "Lucenda Console" Size 11 Right 
         @ 51,103 Print "Art-Photo  Length -- (In, mm)" Font "Lucenda Console" Size 11 Right
         @ 51,108 print ":" Font "Lucenda Console" Size 11
         @ 51,123 print alltrim(str(picl_I)) Font "Lucenda Console" Size 11 Right 
         @ 51,143 Print alltrim(str(round(picl,0))) Font "Lucenda Console" Size 11 Right
         *
         @ 59,103 Print "Base Mat  Overlap -- (mm)" Font "Lucenda Console" Size 11 Right
         @ 59,108 print ":" Font "Lucenda Console" Size 11
         @ 59,123 Print alltrim(str(overlap)) Font "Lucenda Console" Size 11  Right
         *
         @ 64,103 Print "Mat1 to Mat2 Setback - (mm)" Font "Lucenda Console" Size 11 Right
         @ 64,108 print ":" Font "Lucenda Console" Size 11
         if m12 <> 0
         @ 64,123 Print alltrim(str(m12)) Font "Lucenda Console" Size 11  Right
         else
         @ 64,123 Print "" Font "Lucenda Console" Size 11 Right
         endif 
         @ 69,103 Print "Mat2 to Mat3 Setback - (mm)" Font "Lucenda Console" Size 11 Right
         @ 69,108 print ":" Font "Lucenda Console" Size 11
         if m23 <> 0
         @ 69,123 Print alltrim(str(m23)) Font "Lucenda Console" Size 11 Right
         else
         @ 69,123 Print "" Font "Lucenda Console" Size 11 Right
         endif
         @ 77,103 Print "Photo Width  Offset -- (mm)" Font "Lucenda Console" Size 11 Right 
         @ 77,108 print ":" Font "Lucenda Console" Size 11
         if offw <> 0
         @ 77,123 Print alltrim(str(offw)) Font "Lucenda Console" Size 11 Right 
         else
         @ 77,123 Print "" Font "Lucenda Console" Size 11  Right
         endif
         @ 82,103 Print "Photo Length  Offset -- (mm)" Font "Lucenda Console" Size 11 Right
         @ 82,108 print ":" Font "Lucenda Console" Size 11
         if offl <> 0
         @ 82,123 Print alltrim(str(offl)) Font "Lucenda Console" Size 11 Right
         else
         @ 82,123 Print "" Font "Lucenda Console" Size 11 Right
         endif
         @ 90,103 Print "Photo Width  Optical Center" Font "Lucenda Console" Size 11 Right
         @ 90,108 print ":" Font "Lucenda Console" Size 11
         @ 90,123 Print alltrim(str(t3)) Font "Lucenda Console" Size 11 Right      
         @ 95,103 Print "Photo Length Optical Center" Font "Lucenda Console" Size 11 Right
         @ 95,108 print ":" Font "Lucenda Console" Size 11
         @ 95,123 Print alltrim(str(u3)) Font "Lucenda Console" Size 11 Right
         @ 99,108 Print "____________________________________________________________" Center Font "Lucenda Console" Size 11
         *
         @110,103 Print "Mat.1 -- W.1" Font "Lucenda Console" Size 11 Right
         @110,108 print ":" Font "Lucenda Console" Size 11
         @110,123 Print alltrim(str(round(w3,0))) Font "Lucenda Console" Size 11 Right
         @115,103 Print "Mat.1 -- W.2" Font "Lucenda Console" Size 11 Right
         @115,108 print ":" Font "Lucenda Console" Size 11
         @115,123 Print alltrim(str(round(w4,0))) Font "Lucenda Console" Size 11 Right
         @120,103 Print "Mat.1 --- L.1" Font "Lucenda Console" Size 11 Right
         @120,108 print ":" Font "Lucenda Console" Size 11
         @120,123 Print alltrim(str(round(l3,0))) Font "Lucenda Console" Size 11 Right
         @125,103 Print "Mat.1 --- L.2" Font "Lucenda Console" Size 11 Right
         @125,108 print ":" Font "Lucenda Console" Size 11
         @125,123 Print alltrim(str(round(l4,0))) Font "Lucenda Console" Size 11 Right
         *
         if w5>0 .and. w6>0 .and. l5>0 .and. l6>0
         @135,103 Print "Mat.2 -- W.1" Font "Lucenda Console" Size 11 Right
         @135,108 print ":" Font "Lucenda Console" Size 11
         @135,123 Print alltrim(str(round(w5,0))) Font "Lucenda Console" Size 11 Right
         @140,103 Print "Mat.2 -- W.2" Font "Lucenda Console" Size 11 Right
         @140,108 print ":" Font "Lucenda Console" Size 11
         @140,123 Print alltrim(str(round(w6,0))) Font "Lucenda Console" Size 11 Right
         @145,103 Print "Mat.2 --- L.1" Font "Lucenda Console" Size 11 Right
         @145,108 print ":" Font "Lucenda Console" Size 11
         @145,123 Print alltrim(str(round(l5,0))) Font "Lucenda Console" Size 11 Right
         @150,103 Print "Mat.2 --- L.2" Font "Lucenda Console" Size 11 Right
         @150,108 print ":" Font "Lucenda Console" Size 11
         @150,123 Print alltrim(str(round(l6,0))) Font "Lucenda Console" Size 11 Right
         Endif
         * 
         if w7>0 .and. w8>0 .and. l7>0 .and. l8>0 
         @160,103 Print "Mat.3 -- W.1" Font "Lucenda Console" Size 11 Right
         @160,108 print ":" Font "Lucenda Console" Size 11
         @160,123 Print alltrim(str(round(w7,0))) Font "Lucenda Console" Size 11 Right
         @165,103 Print "Mat.3 -- W.2" Font "Lucenda Console" Size 11 Right
         @165,108 print ":" Font "Lucenda Console" Size 11
         @165,123 Print alltrim(str(round(w8,0))) Font "Lucenda Console" Size 11 Right
         @170,103 Print "Mat.3 --- L.1" Font "Lucenda Console" Size 11 Right
         @170,108 print ":" Font "Lucenda Console" Size 11
         @170,123 Print alltrim(str(round(l7,0))) Font "Lucenda Console" Size 11 Right
         @175,103 Print "Mat.3 --- L.2" Font "Lucenda Console" Size 11 Right
         @175,108 print ":" Font "Lucenda Console" Size 11
         @175,123 Print alltrim(str(round(l8,0))) Font "Lucenda Console" Size 11 Right
         Endif 
     END PRINTPAGE             
   END PRINTDOC
  Endif
 Endif 
RETURN NIL 

************************************************************************************************

FUNCTION picload ()
local kurtebert
if Kcalc = 1
if Kphoto = 1
if Rpics = 1
*
CleanSlate ()
kurtebert := Getfile ( { {'All Files','*.jpg'} } , 'Get Photograph' , ' ' , .f. , .t. )
Form_1.img1.picture := kurtebert
if HV = 0
landscape ()
else
Portrait ()
endif
*
endif
endif
endif
RETURN NIL

************************************************************************************************
* End
